@@ -2,7 +2,6 @@
 
 import importlib
 import logging
-import multiprocessing
 import os
 import platform
 import sys
@@ -182,7 +181,7 @@ class TrainerConfig(Coqpit):
         },
     )
     cudnn_benchmark: bool = field(
-        default=True,
+        default=False,
         metadata={
             "help": "Enable/disable cudnn benchmark explicitly. Set this False if your input size change constantly. Defaults to False"
         },
@@ -587,7 +586,6 @@ class Trainer:
     @staticmethod
     def setup_training_environment(args, config, gpu):
         if platform.system() != "Windows":
-            multiprocessing.set_start_method("fork")
             # https://github.com/pytorch/pytorch/issues/973
             import resource  # pylint: disable=import-outside-toplevel
 
@@ -1018,10 +1016,12 @@ class Trainer:
                         loss_dict["amp_scaler"] = scaler.get_scale()  # for logging
                     update_lr_scheduler = scale_prev <= scaler.get_scale()
         else:
+            self.callbacks.before_backward_pass(self, loss_dict)
             # main model optimizer step
             loss_dict["loss"].backward()
             # gradient accumulation
             if step_optimizer:
+                self.callbacks.before_gradient_clipping(self)
                 if grad_clip > 0:
                     grad_norm = torch.nn.utils.clip_grad_norm_(self.master_params(optimizer), grad_clip)
                 optimizer.step()
